#
# spec file for package password-store
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           password-store
Version:        1.7.4
Release:        6.1
Summary:        Utility to store, retrieve, generate and synchronize passwords
License:        GPL-2.0-or-later
URL:            https://zx2c4.com/projects/%{name}/
Source:         https://git.zx2c4.com/password-store/snapshot/%{name}-%{version}.tar.xz
# remove on the next release after 1.7.4
Patch0:         https://git.zx2c4.com/password-store/patch/?id=85bb62f47ac2f518bfdb36c5dfedf5938219a9b7#/default-to-xclip.patch
BuildRequires:  bash-completion
BuildRequires:  git-core
BuildRequires:  gpg2
BuildRequires:  qrencode
BuildRequires:  tree
BuildRequires:  xz
BuildRequires:  zsh
Recommends:     (xclip or wl-clipboard)
Requires:       gpg2
Requires:       qrencode
Requires:       tree >= 1.7.0
Recommends:     pwgen
Suggests:       git-core
BuildArch:      noarch
%if 0%{?suse_version} > 1320
BuildRequires:  fish
%endif

%description
With password-store, each password lives inside of a gpg encrypted file whose
filename is the title of the website or resource that requires the password.
These encrypted files may be organized into meaningful folder hierarchies,
copied from computer to computer, and, in general, manipulated using standard
command line file management utilities.

%package        dmenu
Summary:        A dmenu interface to the "pass" program
Group:          Productivity/Other
Requires:       dmenu
Requires:       password-store
Recommends:     xdotool
BuildArch:      noarch

%description    dmenu
A dmenu interface to "pass", a password manager.

%prep
%autosetup -p1
for shell_script in src/%{name}.sh contrib/dmenu/passmenu; do
    sed -i "s|#\!%{_bindir}/env bash|#\!/bin/bash|" $shell_script
done
# move tests/gnupg to /tmp to avoid too long socket name
d=$(mktemp -d)
mv tests/gnupg $d/.gnupg
ln -s $d/.gnupg tests/gnupg
echo GNUPGHOME=$d/.gnupg >> tests/setup.sh

%build

%install
%make_install FISHCOMP_PATH=%{buildroot}%{_datadir}/fish/completions WITH_ALLCOMP="yes"
install -p -D -m 0755 contrib/dmenu/passmenu %{buildroot}%{_bindir}/passmenu
# own extensions directory for pass plugins
mkdir -p %{buildroot}%{_prefix}/lib/password-store/extensions

%check
%if 0%{?suse_version} >= 1320
%make_build test
%endif

%files
%license COPYING
%doc README
%{_mandir}/man1/pass.1%{?ext_man}
%{_bindir}/pass
%if 0%{?suse_version} <= 1320
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%endif
%{_datadir}/bash-completion/completions/pass
%{_datadir}/fish/vendor_completions.d/pass.fish
%{_datadir}/zsh/site-functions/_pass
%dir %{_prefix}/lib/password-store
%dir %{_prefix}/lib/password-store/extensions

%files dmenu
%doc contrib/dmenu/README.md
%{_bindir}/passmenu

%changelog
* Mon Jun  2 2025 Michael Vetter <mvetter@suse.com>
- Update default-to-xclip.patch it unfortunately contains the
  cgit version
* Sun May 11 2025 Andreas Schwab <schwab@linux-m68k.org>
- Work around too long socket name during testsuite run
* Sun May 29 2022 Matej Cepl <mcepl@suse.com>
- This package should also own
  %%{_prefix}/lib/password-store/extensions directory for other
  pass plugins.
* Tue Dec 14 2021 Marcus Rueckert <mrueckert@suse.de>
- change the requires for the clipboard utilities to recommends
  to lower the foot print for server installations
  by default zypper installs recommends so for most users nothing
  should change.
* Tue Dec 14 2021 Marcus Rueckert <mrueckert@suse.de>
- change the git dependency from git to git-core
  This allows smaller installations on a server
* Fri Sep 24 2021 Dan Čermák <dcermak@suse.com>
- Add patch to fix boo#1185984:
  Added default-to-xclip.patch
* Wed Jul 21 2021 Antonio Larrosa <alarrosa@suse.com>
- Make password-store-dmenu require password-store, as it's
  useless without pass.
* Mon Jun 14 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 1.7.4:
  * Ignore non-printable characters in calls to tree
  * Use GPG_OPTS when verifying .gpg-id signature
  * Strip comments in gpg-id files
  * Escape colons in zsh completion to show url ports
  * passmenu: add support for wayland
  * fish-completion: don't print full path when PASSWORD_STORE_DIR is set
  * Add path to accommodate macOS' dynamic $TMPDIR
  * Add a :redraw to redact_pass.vim before diag print
* Fri May 14 2021 Dan Čermák <dcermak@suse.com>
- boo#1185984: Require either xclip or wl-clipboard
* Tue Mar 23 2021 idonmez@suse.com
- Update to version 1.7.3+git20210216.918992c:
  * fish-completion: reuse "git" and "grep" completions
  * fish-completion: don't erase existing completions for pass
  * fish-completion: force some variables to be script-local
  * fish-completion: support completions for wrapper commands
  * fish-completion: remove obsolete flag
  * fish-completion: avoid printing errors with an empty password store
  * Unset variables messing with Git use
  * Support extractions of secret fields other than password
  * Re add password-store-timeout for backward compatibility
  * Account for missing [:graph:] on Busybox by using [:alnum:][:punct:]
  * Exclude invalid, disabled and revoked subkeys from subkey selection
  * clip: Add support for wl-clipboard
  * bash-completion: detect whether to use gpg/gpg2 binary for complete keys
  * bash_completion: do not leak variables to globals scope
  * Do not reencrypt symbolic links
* Thu Apr 11 2019 Dan Čermák <dcermak@suse.com>
- small fixes to the pass spec file:
  * cleanup rpmlint warnings
  * require xclip instead of recommending it
  * preserve timestamps of fish completion files during installation
* Mon Aug  6 2018 kbabioch@suse.com
- Update to 1.7.3 (bugfix release)
  * Simplify filename matching in redact_pass.vim
  * Do not put passwords in herestrings
  * Do not set foreground color for generated password
  * Add custom bash completion for extensions
  * show: do not store binary data in bash vars
* Sun Jul 29 2018 jengelh@inai.de
- Use noun phrase in summary. Fix double meaning of "pass".
* Fri Jun 15 2018 kbabioch@suse.com
- Update to 1.7.2
  * Large number of bug fixes
  * Fixed the signature verification routine that parses the output of GnuPG.
    Previously, it was prone to spoofing of file signatures and allowed
    attackers to inject additional encryption keys (bsc#1097774
    CVE-2018-12356).
- Applied spec-cleaner
* Thu Nov  9 2017 aavindraa@gmail.com
- Version bump 1.7.1
  * Bug Fixes
  * Add compatibility with GnuPG 2.2.19
  * Uniformly use the $GPG variable
  * Do the correct thing with subkeys when reencrypting
  * Fix test suite on OS X
- Drop password-store-gpg-2.1.patch
  * merged in 6f867674272a03273212259b9039c9356a6ed90
- clean spec file with spec-cleaner
- use %%make_install macro
* Mon Mar 20 2017 werner@suse.de
- Update password-store-gpg-2.1.patch to upstream version done
  by Andreas Stieger
* Fri Mar 10 2017 werner@suse.de
- Version bump 1.7
  * Features
  * Extensions: pass can now load user-defined extensions from a system
    directory or a user directory. There's already a nice ecosystem of
    extensions being built, even at this early stage. See the pass man page for
    more information.
  * Signatures: there is now an option to enforce signatures of the .gpg-id file
    and extensions using an environment variable.
  * QRCodes: generate and show have now learned the --qrcode/-q switch. Note to
    package maintainers: this adds a dependency on the popular qrencode package.
  * Password generation: rather than use pwgen, we now use /dev/urandom more
    directly, which results in more assured password security, as well as
    customizable character sets, via an environment variable. See the pass man
    page for more information on this customization. Package maintainers: you
    may now drop the dependency on pwgen.
  * Importers: there now are several more importers. More and more folks are
    moving to pass!
  * Selectable clipping: you can now specify which line you wish to copy to the
    clipboard or display with a qrcode when using -c or -q.
  * Git discovery: The PASSWORD_STORE_GIT environment variable has been removed,
    and instead pass will automatically choose the git repository closest to the
    file being modified (but not out of the actual password store itself). This
    should help people who like to nest git repos for different organizations.
  * Bug fixes: too many to count.
- New dependency qrencode
- Make pwgen a recommended tool
- Add patch password-store-gpg-2.1.patch to be able to handle new gpg behaviour
  boo#1028867
* Thu Jan 29 2015 tampakrap@opensuse.org
- Add conditionals on dependencies that don't exist on older distros
- Disable tests in older distros where the dependencies don't satisfy them
* Wed Jan 28 2015 tampakrap@opensuse.org
- Version bump 1.6.5:
  * 1.6.4 Changelog:
  * Features:
  * "add" is an alias of "insert"
  * `pass edit` will no longer make a commit if the password does not change
  * Symbolic links are now followed
  * Remove gpg agent check, due to the auto-starting gpg-agent in GnuPG 2.1
  * Bug Fixes:
  * Avoid trailing slash in `pass grep`
  * Account for $CLIP_TIME in messages
  * revelation2pass, keepassx2pass, and other script improvements
  * Fix .gpg extension in tree listings, and preserve colors
  * Improved support for getopt on OSX
  * Updates for zsh and fish completion autoloading
  * Always preserve TTY for pinentry
  * Only use encryption subkeys
  * Better clip error messages
  * No longer use hidden recipients
  * 1.6.5 Changelog:
  * Features:
  * Support Gpg4win alongside Cygwin
  * Bug Fixes:
  * Work around unit tests bug with GnuPG 2.1.0 and 2.1.1
  * Manually migrate unit tests keys to GnuPG 2.1 series
  * Restore support for GnuPG 2.0 series
- Add a few builddeps so that we don't own the dirs of the completion files
* Tue Jul 22 2014 tampakrap@opensuse.org
- Version bump 1.6.3 (no upstream changelog)
- Upstream added tests, enable them in the package (added according Build deps)
- New subpackage password-store-dmenu, that adds passmenu binary
  It is a dmenu interface to pass
- Installation of completion files is fully and properly handled by the Makefile
- Depend on tree 1.7.0
* Tue Jul 22 2014 tampakrap@opensuse.org
- Version bump 1.5.0 (no upstream changelog)
- (not updating to 1.6.3 yet because it requires tree 1.7.0)
- fix installation of completion files (based on 1.6.3 Makefile)
- spec-cleaner
* Wed Jun  5 2013 tchatzimichos@suse.com
- Fix formatting
* Thu Mar 21 2013 tchatzimichos@suse.com
- Fix previous commit: Properly rename zsh completion file to _pass
* Thu Mar 21 2013 tchatzimichos@suse.com
- Rename zsh completion file to _zsh in order to make it detectable by zsh
* Wed Mar 20 2013 tchatzimichos@suse.com
- Add dependencies
* Mon Mar 18 2013 tchatzimichos@suse.com
- Initial commit of password-store package, version 1.4.2
